sequencetools.get_sequence_period_of_rotation
=============================================

.. autofunction:: abjad.tools.sequencetools.get_sequence_period_of_rotation.get_sequence_period_of_rotation
